@@ -28,7 +28,6 @@
 #include "tracker-portal-endpoint.h"
 #include "tracker-portal-utils.h"
 
-typedef struct _TrackerPortal TrackerPortal;
 typedef struct _TrackerSession TrackerSession;
 
 struct _TrackerSession
@@ -192,7 +191,7 @@ endpoint_closed_cb (TrackerPortalEndpoint *endpoint,
                     gpointer               user_data)
 {
 	TrackerPortal *portal = user_data;
-	gint i;
+	guint i;
 
 	for (i = 0; i < portal->sessions->len; i++) {
 		TrackerSession *session;
@@ -368,10 +367,9 @@ portal_iface_method_call (GDBusConnection       *connection,
 		g_dbus_method_invocation_return_value (invocation,
 		                                       g_variant_new ("(o)", session.object_path));
 	} else if (g_strcmp0 (method_name, "CloseSession") == 0) {
-		g_autofree gchar *uri = NULL;
 		g_autofree gchar *object_path = NULL;
 		gboolean found = FALSE;
-		gint i;
+		guint i;
 
 		g_variant_get (parameters, "(o)", &object_path);
 		g_debug ("Got request for closing session '%s'", object_path);
